@@ -1,6 +1,6 @@
 #!/bin/sh
 
-VERSIONMOZ=1.7
+VERSIONMOZ=1.7.6
 VERSIONTRAD=1
 
 pushd bin/chrome
@@ -8,13 +8,13 @@ pushd bin/chrome
 popd
 
 rm -f mozilla-l10n-fr-FR-$VERSIONMOZ-$VERSIONTRAD.xpi
-zip -9 mozilla-l10n-fr-FR-$VERSIONMOZ-$VERSIONTRAD.xpi \
+zip -9 -D mozilla-l10n-fr-FR-$VERSIONMOZ-$VERSIONTRAD.xpi \
 	install.js \
 	`find bin/defaults -not -name 'mozilla-anglais.diff' |\
 		grep -v CVS -` \
-	`find bin/searchplugins -name '*' |\
+	`find bin/searchplugins -not -name 'mozilla-anglais.diff' |\
 		grep -v CVS -` \
-	`find bin/components -name '*' |\
+	`find bin/components -not -name 'mozilla-anglais.diff' |\
                 grep -v CVS -` \
 	bin/chrome/FR.jar \
 	bin/chrome/fr-FR.jar \
