@@ -41,7 +41,7 @@
 var prettyName = "Fran\u00e7ais";
 var langcode = "fr";
 var regioncode = "FR";
-var version = "1.7";
+var version = "1.7.5";
 // --- end pack-specific strings ---
 
 
@@ -57,9 +57,9 @@ function verifyDiskSpace(dirPath, spaceRequired) {
 
   // do the verification
   if(spaceAvailable < spaceRequired) {
-    logComment("Espace disque insuffisant : " + dirPath);
-    logComment("  requis : " + spaceRequired + " Ko");
-    logComment("  disponible : " + spaceAvailable + " Ko");
+    logComment("Espace disque insuffisant\u00a0: " + dirPath);
+    logComment("  requis\u00a0: " + spaceRequired + " Ko");
+    logComment("  disponible\u00a0: " + spaceAvailable + " Ko");
     return(false);
   }
 
@@ -278,31 +278,26 @@ var regionName = "locale/" + regioncode + "/";
 err = initInstall(prettyName, regName, version); 
 logComment("initInstall: " + ErrWithCode(err));
 
-var install_successprofile = "Installation de la langue fran\u00e7aise r\u00e9ussie dans le r\u00e9pertoire de votre profil. Elle ne sera disponible que pour le profil actuel."
-var install_successglobal = "Installation globale de la langue fran\u00e7aise r\u00e9ussie. Elle sera disponible pour tous les profils."
-var tell_reboot = "Vous devez RED\u00c9MARRER votre syst\u00e8me avant de pouvoir s\u00e9lectionner cette langue."
-var tell_restart = "Vous devez RED\u00c9MARRER Mozilla avant de pouvoir s\u00e9lectionner cette langue."
-var howto_switch = "Vous pouvez s\u00e9lectionner cette langue via Edit > Preferences (Cat\u00e9gorie: Appearance > Languages/Content)."
-var install_failed = "L'installation a \u00e9chou\u00e9. Le code d'erreur \u00e9tait"
-var install_cancel = "L'installation a \u00e9t\u00e9 annul\u00e9 avec l'erreur"
-var need_write_perm = "Il semblerait que vous n'ayez pas de permissions en \u00e9criture dans le r\u00e9pertoire 'chrome' de Mozilla. Veuillez installer comme root / administrateur syst\u00e8me."
+var install_successprofile = "Installation de la langue fran\u00e7aise r\u00e9ussie dans le r\u00e9pertoire de votre profil. Elle ne sera disponible que pour le profil actuel.";
+var install_successglobal = "Installation globale de la langue fran\u00e7aise r\u00e9ussie. Elle sera disponible pour tous les profils.";
+var tell_reboot = "Vous devez RED\u00c9MARRER votre syst\u00e8me avant de pouvoir s\u00e9lectionner cette langue.";
+var tell_restart = "Vous devez RED\u00c9MARRER Mozilla avant de pouvoir s\u00e9lectionner cette langue.";
+var howto_switch = "Vous pouvez s\u00e9lectionner cette langue via Edit > Preferences (Cat\u00e9gorie: Appearance > Languages/Content).";
+var install_failed = "L'installation a \u00e9chou\u00e9. Le code d'erreur \u00e9tait";
+var install_cancel = "L'installation a \u00e9t\u00e9 annul\u00e9 avec l'erreur";
+var need_write_perm = "Il semblerait que vous n'ayez pas de permissions en \u00e9criture dans le r\u00e9pertoire 'chrome' de Mozilla. Veuillez installer comme root / administrateur syst\u00e8me.";
 
 fProgram = getFolder("Program");
 logComment("fProgram: " + fProgram);
 
 // searchplugins directory detection
-if (platformNode == 'mac') {
-  fSearchPlugins = getFolder("Program", "Search Plugins");
-}
-else {
-  fSearchPlugins = getFolder("Program", "searchplugins");
-}
+fSearchPlugins = getFolder("Program", "searchplugins");
 logComment("fSearchPlugins: " + fSearchPlugins);
 
 if ((err == 0) && verifyDiskSpace(fProgram, srDest)) {
   // install search plugins first
   err = addDirectory("", "bin/searchplugins", fSearchPlugins, "");
-  logComment("addDirectory() pour searchplugins a retourn\u00e9 : " + ErrWithCode(err));
+  logComment("addDirectory() pour searchplugins a retourn\u00e9\u00a0: " + ErrWithCode(err));
   resetError();
 
   var chromeType = LOCALE;
@@ -310,26 +305,26 @@ if ((err == 0) && verifyDiskSpace(fProgram, srDest)) {
 // well, just try to do it right (tm) on unix as well for Mozilla 1.3 !!!  
 //  if (platformNode == 'unix') {
     // DELAYED_CHROME is still needed on many unix systems for bug 109044; this needs a Mozilla restart!
-//    logComment("d\u00e9tected un syst\u00e8me unix : utilise DELAYED_CHROME pour registerChrome d\u00fb au bug 109044");
+//    logComment("d\u00e9tect\u00e9 un syst\u00e8me unix\u00a0: utilise DELAYED_CHROME pour registerChrome d\u00fb au bug 109044");
 //    chromeType |= DELAYED_CHROME;
 //    tellRestart = 1;
 //  }
   err = addDirectory("", "bin/chrome", fProgram, "chrome");
-  logComment("addDirectory() pour chrome a retourn\u00e9 : " + ErrWithCode(err));
+  logComment("addDirectory() pour chrome a retourn\u00e9\u00a0: " + ErrWithCode(err));
   err = addDirectory("", "bin/defaults/messenger", fProgram, "defaults/messenger");
-  logComment("addDirectory() pour defaults/messenger a retourn\u00e9 : " + ErrWithCode(err));
+  logComment("addDirectory() pour defaults/messenger a retourn\u00e9\u00a0: " + ErrWithCode(err));
   err = addDirectory("", "bin/defaults/profile", fProgram, "defaults/profile");
-  logComment("addDirectory() pour defaults/profile a retourn\u00e9 : " + ErrWithCode(err));
+  logComment("addDirectory() pour defaults/profile a retourn\u00e9\u00a0: " + ErrWithCode(err));
   if (platformNode == 'unix') {
     err = addDirectory("", "bin/defaults/isp", fProgram, "defaults/isp");
-    logComment("addDirectory() pour defaults/isp a retourn\u00e9 : " + ErrWithCode(err));
+    logComment("addDirectory() pour defaults/isp a retourn\u00e9\u00a0: " + ErrWithCode(err));
   }
   err = addDirectory("", "bin/components", fProgram, "components");
-  logComment("addDirectory() pour components a retourn\u00e9 : " + ErrWithCode(err));
+  logComment("addDirectory() pour components a retourn\u00e9\u00a0: " + ErrWithCode(err));
 
   if (err != 0) {
     // return value 0 is SUCCESS
-    logComment("addDirectory() pour " + fProgram + " a \u00e9chou\u00e9!");
+    logComment("addDirectory() pour " + fProgram + " a \u00e9chou\u00e9\u00a0!");
  
 // well, just try to do it right (tm) on unix as well for Mozilla 1.3 !!!  
 //    if (platformNode != 'unix') {
@@ -339,19 +334,19 @@ if ((err == 0) && verifyDiskSpace(fProgram, srDest)) {
       chromeType |= PROFILE_CHROME;
       profileInstall = 1;
       fProgram = getFolder("Profile");
-      logComment("essaie l'installation dans le profil de l'utilisateur : " + fProgram);
+      logComment("essaie l'installation dans le profil de l'utilisateur\u00a0: " + fProgram);
       err = addDirectory("", "bin/chrome", fProgram, "chrome");
-      logComment("addDirectory() pour le profil chrome a return\u00e9 : " + ErrWithCode(err));
+      logComment("addDirectory() pour le profil chrome a retourn\u00e9\u00a0: " + ErrWithCode(err));
       err = addDirectory("", "bin/defaults/messenger", fProgram, "defaults/messenger");
-      logComment("addDirectory() pour le profil chrome (defaults/messenger) a retourn\u00e9 : " + ErrWithCode(err));
+      logComment("addDirectory() pour le profil chrome (defaults/messenger) a retourn\u00e9\u00a0: " + ErrWithCode(err));
       err = addDirectory("", "bin/defaults/profile", fProgram, "defaults/profile");
-      logComment("addDirectory() pour le profil chrome (defaults/profile) a retourn\u00e9 : " + ErrWithCode(err));
+      logComment("addDirectory() pour le profil chrome (defaults/profile) a retourn\u00e9\u00a0: " + ErrWithCode(err));
       if (platformNode == 'unix') {
         err = addDirectory("", "bin/defaults/isp", fProgram, "defaults/isp");
-        logComment("addDirectory() pour le profil chrome (defaults/isp) a retourn\u00e9 : " + ErrWithCode(err));
+        logComment("addDirectory() pour le profil chrome (defaults/isp) a retourn\u00e9\u00a0: " + ErrWithCode(err));
       }
       err = addDirectory("", "bin/components", fProgram, "components");
-      logComment("addDirectory() pour le profil chrome (components) a retourn\u00e9 : " + ErrWithCode(err));
+      logComment("addDirectory() pour le profil chrome (components) a retourn\u00e9\u00a0: " + ErrWithCode(err));
 //    }
 //    else {
 //      logComment("ne peut pas utiliser le profil de l'utilisateur \u00e0 cause du bug 109044");
@@ -417,7 +412,7 @@ if ((err == 0) && verifyDiskSpace(fProgram, srDest)) {
     registerChrome(chromeType, rf, regionName + "navigator-region/");
 
     err = performInstall(); 
-    logComment("performInstall() a return\u00e9 : " + ErrWithCode(err));
+    logComment("performInstall() a retourn\u00e9\u00a0: " + ErrWithCode(err));
     if (err == 999) {
       if (platformNode == 'win') {
         tellRestart = 1;
@@ -454,7 +449,7 @@ if ((err == 0) && verifyDiskSpace(fProgram, srDest)) {
   }
   else {
     cancelInstall(err);
-    logComment("cancelInstall d\u00fb \u00e0 l'erreur : " + ErrWithCode(err));
+    logComment("cancelInstall d\u00fb \u00e0 l'erreur\u00a0: " + ErrWithCode(err));
     alertstring = install_cancel + " " + ErrWithCode(err) + ".";
     if ((err == -202) || (err == -215)) {
       // -202 is ACCESS_DENIED, -215 is READ_ONLY
